@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.37 2004/07/19 21:13:16 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.41 2004/11/14 16:40:44 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -109,15 +109,6 @@ get_int_resource(enum res_type rtype, int *intval)
 }
 
 
-/* Get keyboard equivalent from first character of localised string. */
-
-void
-get_key_val(int *val, char *str)
-{
-    *val = str[0];
-}
-
-
 /* Return the radix character. For most locales, this is a period. 
  * If nl_langinfo(RADIXCHAR) returns an empty string, return ",".
  */
@@ -161,10 +152,10 @@ get_options(int argc, char *argv[])      /* Extract command line options. */
                     INC;
                     getparam(next, argv, _("-a needs accuracy value"));
                     v->accuracy = atoi(next);
-                    if (v->accuracy < 0 || v->accuracy > 9) {
+                    if (v->accuracy < 0 || v->accuracy > MAXACC) {
                         FPRINTF(stderr, 
-                                _("%s: accuracy should be in the range 0-9\n"),
-                                v->progname);
+                                _("%s: accuracy should be in the range 0-%d\n"),
+                                v->progname, MAXACC);
                         v->accuracy = 9;
                     }
                     break;
@@ -316,9 +307,9 @@ read_resources()    /* Read all possible resources from the database. */
 
     if (get_int_resource(R_ACCURACY, &intval)) {
         v->accuracy = intval;
-        if (v->accuracy < 0 || v->accuracy > 9) {
-            FPRINTF(stderr, _("%s: accuracy should be in the range 0-9\n"), 
-                    v->progname);
+        if (v->accuracy < 0 || v->accuracy > MAXACC) {
+            FPRINTF(stderr, _("%s: accuracy should be in the range 0-%d\n"), 
+                    v->progname, MAXACC);
             v->accuracy = 9;
         }
     }
